//! A command parsing and evaluation library for a LISP dialect, specialized for commandline input.
#![deny(missing_docs)]

//pub mod values;
pub mod lexer;
pub mod parser;
